@@ -16,8 +16,9 @@ class QueryMethod(Query):
         args: Optional[Dict[str, Any]] = None,
         fields: Optional[List[str | DataclassType | QueryMethod]] = None,
         indents: int = 4,
+        start_indent: int = 0,
     ):
-        super().__init__(dataclass_schema, fields, indents)
+        super().__init__(dataclass_schema, fields, indents, start_indent)
         self.method_name = method_name
         self.dataclass_schema = dataclass_schema
         self.args = args or {}
@@ -31,7 +32,10 @@ class QueryMethod(Query):
                 argument_list.append(f"{key}: {str(value).lower()}")
             else:
                 argument_list.append(f"{key}: {value}")
-        return " " * indents + f"{self.method_name}({', '.join(argument_list)})"
+        return (
+            " " * (self.start_indent + indents)
+            + f"{self.method_name}({', '.join(argument_list)})"
+        )
 
     def _generate_query(self, indents: int = 4) -> str:
         return f"{self._create_method_head(indents-4)} " + super()._generate_query(
